@@ -180,6 +180,10 @@ class SyncClientGenerator:
         self.g.P("    if err is not None:")
         self.g.P("        raise err")
         self.g.P("    yield from stream_output")
+        self.g.P("    err = stream_output.error()")
+        self.g.P("    if err is not None:")
+        self.g.P("        raise err")                
+        
         self.g.P()
 
         self.g.P("def call_", m.py_name, "(")
@@ -247,6 +251,10 @@ class SyncClientGenerator:
         self.g.P("    if err is not None:")
         self.g.P("        raise err")
         self.g.P("    yield from stream_output")
+        self.g.P("    err = stream_output.error()")
+        self.g.P("    if err is not None:")
+        self.g.P("        raise err")                
+        
         self.g.P()
 
         # Stream method for metadata access
@@ -368,6 +376,9 @@ class AsyncClientGenerator:
         self.g.P("    async with stream_output as stream:")
         self.g.P("        async for response in stream:")
         self.g.P("            yield response")
+        self.g.P("        err = stream.error()")
+        self.g.P("        if err is not None:")
+        self.g.P("            raise err")                
         self.g.P()
 
         self.g.P("async def call_", m.py_name, "(")
@@ -446,6 +457,10 @@ class AsyncClientGenerator:
         self.g.P("    async with stream_output as stream:")
         self.g.P("        async for response in stream:")
         self.g.P("            yield response")
+        self.g.P("        err = stream.error()")
+        self.g.P("        if err is not None:")
+        self.g.P("            raise err")                
+        
         self.g.P()
 
         # Stream method for metadata access
